package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.AccessRecord;

/**
 * 访问记录Mapper接口
 * 
 * @author ruoyi
 * @date 2024-02-27
 */
public interface AccessRecordMapper 
{
    /**
     * 查询访问记录
     * 
     * @param recordId 访问记录主键
     * @return 访问记录
     */
    public AccessRecord selectAccessRecordByRecordId(Long recordId);

    /**
     * 查询访问记录列表
     * 
     * @param accessRecord 访问记录
     * @return 访问记录集合
     */
    public List<AccessRecord> selectAccessRecordList(AccessRecord accessRecord);

    /**
     * 新增访问记录
     * 
     * @param accessRecord 访问记录
     * @return 结果
     */
    public int insertAccessRecord(AccessRecord accessRecord);

    /**
     * 修改访问记录
     * 
     * @param accessRecord 访问记录
     * @return 结果
     */
    public int updateAccessRecord(AccessRecord accessRecord);

    /**
     * 删除访问记录
     * 
     * @param recordId 访问记录主键
     * @return 结果
     */
    public int deleteAccessRecordByRecordId(Long recordId);

    /**
     * 批量删除访问记录
     * 
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAccessRecordByRecordIds(Long[] recordIds);
}
